(function() {
	tpl.at = {};
	
	/**
	* Add the titles of the test cases to the list to get them loaded to the table view
	*/
	tpl.at.createData = function () {
		var acceptanceData = [
			{title:'TIMOB2613', hasChild:true, level:"acceptance"},
			{title:'TIMOB4466', hasChild:true, level:"acceptance"},
			{title:'TIMOB4469', hasChild:true, level:"acceptance"},
			{title:'TIMOB6371', hasChild:true, level:"acceptance"},
			{title:'TIMOB6932', hasChild:true, level:"acceptance"},
			{title:'TIMOB6748', hasChild:true, level:'acceptance'},
			{title:'TIMOB6756', hasChild:true, level:'acceptance'},
			{title:'TIMOB7605', hasChild:true, level:'acceptance'}
		]
		
		return acceptanceData;
	};
	
	
	/**
	* TIMOB_4466 is designed to test the correct functionality of the Filesystem
	* when getting screenshots on iOS 4 retina simulator/device.
	*/
	tpl.at.TIMOB4466 = function (_window) {
		
		var platform = Ti.Platform.osname;
		
		if (platform == 'iphone') {
			
			var displayCaps = Ti.Platform.displayCaps;
			// Check to see if we are running on a retina display
			if (displayCaps.density === 'high') {
				Ti.Media.takeScreenshot(function(event) {
				
    				var shotFile = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, 'screenshot.png');
    			
    				shotFile.write(event.media);
    			
    				var label = Ti.UI.createLabel({text:'Check this path for image file:\n' + shotFile.nativePath});
    			
    				_window.add(label);
				});
			} else {
				var label = Ti.UI.createLabel({text:'This is an iPhone Retina display test, retry on retina device.'});
    			
    			_window.add(label);
			}
			
		} else {
			
			var label = tpl.ui.getSkipLabel();
			_window.add(label);
		}
		
		return _window;
	}
	
	// TIMOB-4469 is designed to test that Filesystem.exists() returns the correct values on directories
	// that exist and do not exist
	//
	tpl.at.TIMOB4469 = function(_window) {
		
		var resourcesFileDoesExist = Ti.Filesystem.getFile(Ti.Filesystem.resourcesDirectory, 'app.js');
		var resourcesFileDoesNotExist = Ti.Filesystem.getFile(Ti.Filesystem.resourcesDirectory, 'this-file-does-not-exist.js');

		var newFile = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, 'this-file-exists.js');
		newFile.write("testing a file");

		var appDataFileDoesExist = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, 'this-file-exists.js');
		var appDataFileDoesNotExist = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, 'this-file-does-not-exist.js');

		
		var label = Ti.UI.createLabel({
			color : '#999'
		});
		label.text = '*** Resources Dir: \nTest presence of file that exists => ' + resourcesFileDoesExist.exists() + '\nTest presence of file that does not exist => ' + resourcesFileDoesNotExist.exists() + '\n\n*** appData Dir: \nTest presence of file that exists => ' + appDataFileDoesExist.exists() + '\nTest presence of file that does not exist => ' + appDataFileDoesNotExist.exists();

		_window.add(label);

		
		return _window;
	}
	
	//
	// TIMOB-6371
	// Android: CommonJS apps crashing on android (V8 + Rhino) on Windows 7 / XP
	//
	tpl.at.TIMOB6371 = function (_window)
	{
		
		if(Ti.Platform.osname != 'android'){
			var label = tpl.ui.getSkipLabel();
			_window.add(label);
		} else {
			
			// This is a single context application with mutliple windows in a stack
			(function() {

				var applicationWindow = require('ApplicationWindow').ApplicationWindow;
				_window = new applicationWindow();
			})();

		}
		
		return _window;
	}
	/* TIMOB-2613 is designed to test that accessing cached images on Android works correctly
	 * 
	 */
	tpl.at.TIMOB2613 = function (_window) {
		
		if(Ti.Platform.osname != 'android'){
			var label = tpl.ui.getSkipLabel();
			_window.add(label);
		} else {
			
			var webview = Ti.UI.createImageView({
				top : 0,
				left : 0,
				width : 100,
				height : 50,
				image : 'http://www.appcelerator.com/wp-content/themes/appcelerator/img/APPC_logo.png'
			});

			_window.add(webview);

		}
		
		return _window;
	}
	
	// TIMOB-6932: tests using Ti.Filesystem.File.writeable and Ti.Filesystem.File.getWriteable() get prints out a warning in the console/logcat
	tpl.at.TIMOB6932 = function(_window) {
		
		var f = Titanium.Filesystem.getFile(Titanium.Filesystem.resourcesDirectory, 'text.txt');
		
		if((Ti.Platform.osname === 'iphone') || (Ti.Platform.osname === 'ipad')) {
			var label_writeable = Ti.UI.createLabel({
				height:'auto',
				width:'auto',
				top: 50
			});
			
			label_writeable.text = 'deprecated writeable: ' + f.writeable;
			_window.add(label_writeable);
			
			var label_getWriteable = Ti.UI.createLabel({
				height:'auto',
				width:'auto',
				top: 70
			});
			
			label_getWriteable.text = 'deprecated getWriteable(): ' + f.getWriteable();
			_window.add(label_getWriteable);
			
		}
		
		var label_writable = Ti.UI.createLabel({
				height:'auto',
				width:'auto',
				top: 150
		});
		
		label_writable.text = 'writable: ' + f.writable;
		_window.add(label_writable);
		
		var label_getWritable = Ti.UI.createLabel({
			height:'auto',
			width:'auto',
			top:170
		});
		
		label_getWritable.text = 'getWritable(): ' + f.getWritable();
		_window.add(label_getWritable);
		
		return _window
	};
	
	/* TIMOB-6748 is designed to test that database features work with the filesystem
	 * 
	 */
	tpl.at.TIMOB6748 = function(_window) {
		
		if(Ti.Platform.osname === 'android') {
			_window.add(tpl.ui.getSkipLabel());
			return _window;
		}
		
		var d = Ti.Database.open('testdb.db');
		var f = d.file;
		alert(f.path);


		return _window;
	}
	
	/* TIMOB-6756 is designed to test that database works correctly
	 * 
	 */
	tpl.at.TIMOB6756 = function(_window) {
		
		
		var db = Titanium.Database.open('mydb');

		var l3 = Titanium.UI.createLabel({
			text : 'unicode placeholder',
			width : 300,
			height : 40,
			top : 160
		});
		_window.add(l3);

		var l = Titanium.UI.createLabel({
			text : 'See Log for output',
			top : 10,
			left : 10,
			height : 'auto',
			width : 'auto'
		});
		_window.add(l);

		var b1 = Titanium.UI.createButton({
			title : 'Create the DB',
			width : 200,
			height : 40,
			top : 40
		});
		_window.add(b1);

		b1.addEventListener('click', function() {
			var l1 = Titanium.UI.createLabel({
				text : '2nd context test - see log.',
				color : '#fff',
				font : {
					fontSize : 14
				},
				width : 'auto',
				height : 'auto'
			});

			_window.add(l1);
			var db = Titanium.Database.open('mydb');
			db.execute('CREATE TABLE IF NOT EXISTS DATABASETEST  (ID INTEGER, NAME TEXT)');
			db.execute('DELETE FROM DATABASETEST');

			db.execute('INSERT INTO DATABASETEST (ID, NAME ) VALUES(?,?)', 1, 'Name 1');
			db.execute('INSERT INTO DATABASETEST (ID, NAME ) VALUES(?,?)', 2, 'Name 2');
			db.execute('INSERT INTO DATABASETEST (ID, NAME ) VALUES(?,?)', 3, 'Name 3');
			db.execute('INSERT INTO DATABASETEST (ID, NAME ) VALUES(?,?)', 4, 'Name 4');
			db.execute('INSERT INTO DATABASETEST (ID, NAME ) VALUES(?,?)', 5, '\u2070 \u00B9 \u00B2 \u00B3 \u2074 \u2075 \u2076 \u2077 \u2078 \u2079');
			var updateName = 'I was updated';
			var updateId = 4;
			db.execute('UPDATE DATABASETEST SET NAME = ? WHERE ID = ?', updateName, updateId);

			db.execute('UPDATE DATABASETEST SET NAME = "I was updated too" WHERE ID = 2');

			db.execute('DELETE FROM DATABASETEST WHERE ID = ?', 1);

			Titanium.API.info('JUST INSERTED, rowsAffected = ' + db.rowsAffected);
			Titanium.API.info('JUST INSERTED, lastInsertRowId = ' + db.lastInsertRowId);
			db.close();
		});
		var b2 = Titanium.UI.createButton({
			title : 'Select on the db',
			width : 200,
			height : 40,
			top : 100
		});
		_window.add(b2);

		b2.addEventListener('click', function() {
			var db = Titanium.Database.open('mydb');
			var rows = db.execute('SELECT * FROM DATABASETEST');
			Titanium.API.info('ROW COUNT = ' + rows.getRowCount());
			Titanium.API.info('ROW COUNT = ' + rows.getRowCount());
			Titanium.API.info('ROW COUNT = ' + rows.getRowCount());

			while(rows.isValidRow()) {
				Titanium.API.info('ID: ' + rows.field(0) + ' NAME: ' + rows.fieldByName('name') + ' COLUMN NAME ' + rows.fieldName(0));
				if(rows.field(0) == 5) {
					l3.text = rows.fieldByName('name');
				}

				rows.next();
			}
			rows.close();
			db.close();
			// close db when you're done to save resources
			var l2 = Titanium.UI.createLabel({
				text : 'Check the select - see log.',
				color : '#fff',
				font : {
					fontSize : 14
				},
				width : 'auto',
				height : 'auto',
				top : 400,
			});
			_window.add(l2);
		});
		var l3 = Titanium.UI.createLabel({
			text : 'unicode placeholder',
			width : 300,
			height : 40,
			top : 160
		});


		
		return _window;
	}
	

	/*
	 * iOS: httpClient file transfers appear to be cached in 1.8.0.1
	 */
	tpl.at.TIMOB7605 = function(_window) {
		/*
		 * TEST 1.8.X DOWNLOADING THE SAME FILE MULTIPLE TIMES
		 *
		 * NOTE: Will need to create: Titanium.Filesystem.applicationDataDirectory + "/projects/" + p[1-5] to write into
		 */

		for(var i = 1; i <= 5; i++) {
			var file = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, "projects", "p" + i);
			if(!file.exists()) {
				file.createDirectory(true);
			}
		}

		function jsleep(s) {
			s = s * 1000;
			var a = true;
			var n = new Date();
			var w;
			var sMS = n.getTime();
			while(a) {
				w = new Date();
				wMS = w.getTime();
				if(wMS - sMS > s)
					a = false;
			}
		}

		var button1 = Titanium.UI.createButton({
			top : '10',
			title : 'Test Downloading Same File 5 Times (1.8.X)',
			width : '400',
			height : '40'
		});

		button1.addEventListener('click', function() {
			downloadafile("p1", "g.jpg", "http://www.gonzoville.com/wp-content/uploads/2011/12/0.jpeg");
			jsleep(1);
			downloadafile("p2", "g.jpg", "http://www.gonzoville.com/wp-content/uploads/2011/12/0.jpeg");
			//jsleep(1);
			downloadafile("p3", "g.jpg", "http://www.gonzoville.com/wp-content/uploads/2011/12/0.jpeg");
			//jsleep(1);
			downloadafile("p4", "g.jpg", "http://www.gonzoville.com/wp-content/uploads/2011/12/0.jpeg");
			//jsleep(1);
			downloadafile("p5", "g.jpg", "http://www.gonzoville.com/wp-content/uploads/2011/12/0.jpeg");

		});

		_window.add(button1);

		Ti.API.info("BASE PATH: " + Titanium.Filesystem.applicationDataDirectory);


		function downloadafile(foldername, filename, fileurl) {
			var c = Titanium.Network.createHTTPClient({
				timeout : 10000,

				onload : function(e) {
					Ti.API.info('LOADED ' + filename + " TO " + foldername);

					//var f = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory + "/projects/" + foldername + "/" + filename);
					//f.write(c.responseData);
					Ti.API.info(c.status);
				},
				ondatastream : function(e) {
					Ti.API.info('ONDATASTREAM - PROGRESS: ' + e.progress);
					//if (e.progress == 1) {
					//	Ti.API.info('ONDATASTREAM - LOADED ' + filename + " TO " + foldername);
					//}
				},
				onerror : function(e) {
					Ti.API.info('XHR Error ' + e.error);
				}
			});

			c.clearCookies("all");
			c.open('GET', fileurl);
			c.file = Titanium.Filesystem.getFile(Titanium.Filesystem.applicationDataDirectory + "/projects/" + foldername + "/" + filename);
			c.send();

		}

		return _window;
	}

})();